@@ -86,7 +86,7 @@
 #define KXMLGUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KXMLGUI_NO_DEPRECATED
-#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KXMLGUI_NO_DEPRECATED_WARNINGS
 #  define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KXMLGUI_DEPRECATED_WARNINGS_SINCE KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -137,5 +137,12 @@
 #define KXMLGUI_DEPRECATED_VERSION_5(minor, text)      KXMLGUI_DEPRECATED_VERSION_5_##minor(text)
 #define KXMLGUI_DEPRECATED_VERSION(major, minor, text) KXMLGUI_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KXMLGUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KXMLGUI_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KXMLGUI_DEPRECATED_VERSION(major, minor, text)
+#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KXMLGUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KXMLGUI_EXPORT_H */
